@@ -316,7 +316,20 @@ class RouterMap():
                 SimpleRouter(c, prefix=base_prefix+"/"+c.__tablename__, tags=[c.__tablename__])
                 )
         return AutoMap
-        
+    
+    @classmethod
+    def update_map(cls, simple_router: SimpleRouter):
+        """
+        Add your fastapi_simple_crud.SimpleRouter object to be generated outside of the router map
+        """
+        cls.__dict__[simple_router.tablename] = simple_router
+
+    @classmethod
+    def generate(cls, application: Optional[FastAPI] = None, session_getter: Optional[FunctionType] = None):
+        if cls == RouterMap:
+            return SimpleCRUDGenerator(application, session_getter, True)
+        e = "RouterMap.generate() only able to be called from 'RouterMap' class"
+        raise BaseException(e)
 
 class SimpleCRUDGenerator():
     """
